import type { JwaEncryptionAlgorithm } from '../jwa/alg';
import type { JwkJson } from './Jwk';
import { KeyType } from '../../KeyType';
import { JwaCurve, JwaKeyType } from '../jwa';
import { JwaSignatureAlgorithm } from '../jwa/alg';
import { Jwk } from './Jwk';
export declare class P384Jwk extends Jwk {
    static readonly supportedEncryptionAlgorithms: JwaEncryptionAlgorithm[];
    static readonly supportedSignatureAlgorithms: JwaSignatureAlgorithm[];
    static readonly keyType = KeyType.P384;
    private readonly affinePoint;
    constructor({ x, y }: {
        x: string | Uint8Array;
        y: string | Uint8Array;
    });
    get kty(): JwaKeyType.EC;
    get crv(): JwaCurve.P384;
    get keyType(): KeyType;
    get supportedEncryptionAlgorithms(): JwaEncryptionAlgorithm[];
    get supportedSignatureAlgorithms(): JwaSignatureAlgorithm[];
    get x(): string;
    get y(): string;
    /**
     * Returns the uncompressed public key of the P-384 JWK.
     */
    get publicKey(): Uint8Array;
    /**
     * Returns the compressed public key of the P-384 JWK.
     */
    get publicKeyCompressed(): Uint8Array;
    toJson(): P384JwkJson;
    static fromJson(jwk: JwkJson): P384Jwk;
    static fromPublicKey(publicKey: Uint8Array): P384Jwk;
}
export interface P384JwkJson extends JwkJson {
    kty: JwaKeyType.EC;
    crv: JwaCurve.P384;
    x: string;
    y: string;
    use?: 'sig' | 'enc';
}
export declare function isValidP384JwkPublicKey(jwk: JwkJson): jwk is P384JwkJson;
